@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: client.c,v 1.60 2006/06/05 10:20:54 evertonm Exp $ */
+/* $Id: client.c,v 1.61 2006/06/05 15:52:01 evertonm Exp $ */
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -122,7 +122,7 @@ static void *on_tcp_read(oop_source *src, int sd,
   ++session->keepalives_recv;
 
   /* modifies 'session->seed' */
-  tcp_check_data(sd, session, buf, rd);
+  tcp_check_data(sd, session, (unsigned char *) buf, rd);
 
   nepim_session_read_add(session, rd + session->overhead);
 
@@ -152,7 +152,7 @@ static void *on_tcp_write(oop_source *src, int sd,
 
   old_seed = session->seed;
   /* modifies 'session->seed' */
-  fill_packet_data(session, buf, 0, to_write);
+  fill_packet_data(session, (unsigned char *) buf, 0, to_write);
 
   wr = write(sd, buf, to_write);
   if (wr < 0) {
@@ -182,7 +182,7 @@ static void *on_tcp_write(oop_source *src, int sd,
       /* rewind seed to use exactly 'wr' bytes */
       session->seed = old_seed;
       /* modifies 'session->seed' */
-      fill_packet_data(session, buf, 0, wr);
+      fill_packet_data(session, (unsigned char *) buf, 0, wr);
   }
 
   assert(wr >= 0);
@@ -248,7 +248,7 @@ static void *on_tcp_rate_write(oop_source *src, int sd,
 
   old_seed = session->seed;
   /* modifies 'session->seed' */
-  fill_packet_data(session, buf, 0, to_write);
+  fill_packet_data(session, (unsigned char *) buf, 0, to_write);
 
   wr = write(sd, buf, to_write);
   if (wr < 0) {
@@ -278,7 +278,7 @@ static void *on_tcp_rate_write(oop_source *src, int sd,
       /* rewind seed to use exactly 'wr' bytes */
       session->seed = old_seed;
       /* modifies 'session->seed' */
-      fill_packet_data(session, buf, 0, wr);
+      fill_packet_data(session, (unsigned char *) buf, 0, wr);
   }
 
   assert(wr >= 0);
@@ -448,7 +448,7 @@ static int greet(int sd)
   opt.write_ceil              = nepim_global.server_write_ceil;
 
   if (nepim_global.password) {
-    opt.password_buf      = nepim_global.password;
+    opt.password_buf      = (char *) nepim_global.password;
     opt.password_buf_size = strlen(nepim_global.password) + 1;
   }
   else {
@@ -998,7 +998,7 @@ static void parse_hosts(const char *host_list)
 
     /* split host/port */
     if (addr_split_port(hostname, sizeof(hostname), &portname))
-      portname = nepim_global.portname;
+      portname = (char *) nepim_global.portname;
 
     /* create sockets */
     for (i = 0; i < nepim_global.pipes; ++i)
