@@ -21,7 +21,7 @@ MA 02110-1301 USA
 /*
   nepim - network pipemeter
 
-  $Id: main.c,v 1.55 2006/05/23 20:38:41 evertonm Exp $
+  $Id: main.c,v 1.58 2006/06/02 14:24:38 evertonm Exp $
  */
 
 #include <stdlib.h>
@@ -144,6 +144,12 @@ static void usage(FILE *out, const char *prog_name)
 	  "                 nagle: -1 = use system's default\n"
 	  "                         0 = off (enable TCP_NODELAY)\n"
 	  "                         1 = on (disable TCP_NODELAY)\n"
+	  "  -sweep lo,hi,s sweep write size from 'lo' to 'hi' at step 's'\n"
+	  "                 if lo=\"auto\", lo is minimum size\n"
+	  "                 if hi=\"auto\", hi is maximum size\n"
+	  "                 'lo' must be lower than 'hi'\n"
+	  "                 if s is negative, sweeps from 'hi' to 'lo'\n"
+	  "                 if s=\"random\", sweeps randomly\n"
 	  "\n"
           "server-only options:\n"
           "  -f [lib-name]  enable TCP wrapper filtering\n"
@@ -236,6 +242,54 @@ int main(int argc, const char *argv[])
   for (i = 1; i < argc; ++i) {
     const char *arg = argv[i];
 
+    if (!strcmp(arg, "-sweep")) {
+      int j = i + 1;
+
+      nepim_global.write_floor = -2; /* auto: floor=min */
+      nepim_global.write_ceil  = -2; /* auto: ceil=max */
+
+      if (j < argc) {
+	const char *range = argv[j];
+        if (*range != '-') {
+	  char lo[100];
+	  char *hi;
+	  char *step;
+	  
+          ++i;
+
+	  assert(strlen(range) < (sizeof lo));
+	  strncpy(lo, range, sizeof lo);
+	  lo[(sizeof lo) - 1] = '\0';
+
+	  /* range == lo,hi ? */
+	  if (nepim_str_split_comma(lo, sizeof lo, &hi)) {
+	    fprintf(stderr, "%s: malformed sweep range: %s (from '%s')\n",
+		    nepim_global.prog_name, lo, range);
+	    exit(1);
+	  }
+
+	  /* hi == hi,step ? */
+	  if (!nepim_str_split_comma(hi, (sizeof lo) - (hi - lo), &step)) {
+	    if (strcmp(step, "random"))
+	      nepim_global.sweep_step = atoi(step);
+	    else
+	      nepim_global.sweep_random = 1; /* true */
+	  }
+
+	  if (strcmp(lo, "auto"))
+	    nepim_global.write_floor = atoi(lo);
+
+	  if (strcmp(hi, "auto"))
+	    nepim_global.write_ceil = atoi(hi);
+        }
+      }
+
+      nepim_global.server_write_floor = nepim_global.write_floor;
+      nepim_global.server_write_ceil = nepim_global.write_ceil;
+
+      continue;
+    }
+
     if (!strcmp(arg, "-D")) {
       ++i;
       if (i >= argc) {
@@ -769,16 +823,73 @@ int main(int argc, const char *argv[])
 
   if (nepim_global.client_mode) {
 
-    if (nepim_global.udp_mode)
+    if (nepim_global.udp_mode) {
+
+      nepim_conf_write_sweep_auto(1 /* udp=true */,
+				  &nepim_global.write_floor,
+				  &nepim_global.write_ceil);
+
+      if (nepim_global.write_floor < UDP_HEADER_LEN) {
+        fprintf(stderr, "%s: excessively low UDP write sweep floor=%d (min=%d)\n",
+                nepim_global.prog_name, nepim_global.write_floor, UDP_HEADER_LEN);
+	exit(1);
+      }
+
+      if (nepim_global.write_ceil > nepim_global.udp_write_size) {
+        fprintf(stderr, "%s: excessively high UDP write sweep ceil=%d (max=%d)\n",
+                nepim_global.prog_name, nepim_global.write_ceil,
+		nepim_global.udp_write_size);
+	exit(1);
+      }
+
+      if (nepim_global.write_floor > nepim_global.write_ceil) {
+        fprintf(stderr, "%s: UDP write sweep floor=%d higher than ceil=%d\n",
+                nepim_global.prog_name,
+		nepim_global.write_floor,
+		nepim_global.write_ceil);
+	exit(1);
+      }
+
+      assert(nepim_global.write_floor >= UDP_HEADER_LEN);
+      assert(nepim_global.write_ceil <= nepim_global.udp_write_size);
+      assert(nepim_global.write_floor <= nepim_global.write_ceil);
+
       fprintf(stderr, 
-              "client: udp_read=%d udp_write=%d\n",
-              nepim_global.udp_read_size,
-              nepim_global.udp_write_size);
-    else
+              "client: udp_read=%d udp_write=%d write_floor=%d write_ceil=%d\n",
+              nepim_global.udp_read_size, nepim_global.udp_write_size,
+	      nepim_global.write_floor, nepim_global.write_ceil);
+    }
+    else {
+
+      nepim_conf_write_sweep_auto(0 /* udp=false */,
+				  &nepim_global.write_floor,
+				  &nepim_global.write_ceil);
+
+      if (nepim_global.write_ceil > nepim_global.tcp_write_size) {
+        fprintf(stderr, "%s: excessively high TCP write sweep ceil=%d (max=%d)\n",
+                nepim_global.prog_name, nepim_global.write_ceil,
+		nepim_global.tcp_write_size);
+	exit(1);
+      }
+
+      if (nepim_global.write_floor > nepim_global.write_ceil) {
+        fprintf(stderr, "%s: TCP write sweep floor=%d higher than ceil=%d\n",
+                nepim_global.prog_name,
+		nepim_global.write_floor,
+		nepim_global.write_ceil);
+	exit(1);
+      }
+
+      assert(nepim_global.write_floor >= 0);
+      assert(nepim_global.write_ceil <= nepim_global.tcp_write_size);
+      assert(nepim_global.write_floor <= nepim_global.write_ceil);
+
       fprintf(stderr, 
-              "client: tcp_read=%d tcp_write=%d\n",
-              nepim_global.tcp_read_size,
-              nepim_global.tcp_write_size);
+              "client: tcp_read=%d tcp_write=%d write_floor=%d write_ceil=%d step=%d\n",
+              nepim_global.tcp_read_size, nepim_global.tcp_write_size,
+	      nepim_global.write_floor, nepim_global.write_ceil,
+	      nepim_global.sweep_step);
+    }
 
     nepim_client_run();
 
