@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: server.c,v 1.72 2006/06/05 10:20:54 evertonm Exp $ */
+/* $Id: server.c,v 1.73 2006/06/05 15:52:01 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -108,7 +108,7 @@ static void *on_tcp_read(oop_source *src, int sd,
   ++session->keepalives_recv;
   
   /* modifies 'session->seed' */
-  tcp_check_data(sd, session, buf, rd);
+  tcp_check_data(sd, session, (unsigned char *) buf, rd);
 
   nepim_session_read_add(session, rd + session->overhead);
 
@@ -138,7 +138,7 @@ static void *on_tcp_write(oop_source *src, int sd,
 
   old_seed = session->seed;
   /* modifies 'session->seed' */
-  fill_packet_data(session, buf, 0, to_write);
+  fill_packet_data(session, (unsigned char *) buf, 0, to_write);
 
   wr = write(sd, buf, to_write);
   if (wr < 0) {
@@ -168,7 +168,7 @@ static void *on_tcp_write(oop_source *src, int sd,
       /* rewind seed to use exactly 'wr' bytes */
       session->seed = old_seed;
       /* modifies 'session->seed' */
-      fill_packet_data(session, buf, 0, wr);
+      fill_packet_data(session, (unsigned char *) buf, 0, wr);
   }
 
   assert(wr >= 0);
@@ -234,7 +234,7 @@ static void *on_tcp_rate_write(oop_source *src, int sd,
 
   old_seed = session->seed;
   /* modifies 'session->seed' */
-  fill_packet_data(session, buf, 0, to_write);
+  fill_packet_data(session, (unsigned char *) buf, 0, to_write);
 
   wr = write(sd, buf, to_write);
   if (wr < 0) {
@@ -264,7 +264,7 @@ static void *on_tcp_rate_write(oop_source *src, int sd,
       /* rewind seed to use exactly 'wr' bytes */
       session->seed = old_seed;
       /* modifies 'session->seed' */
-      fill_packet_data(session, buf, 0, wr);
+      fill_packet_data(session, (unsigned char *) buf, 0, wr);
   }
 
   assert(wr >= 0);
@@ -1098,7 +1098,7 @@ static void parse_listeners(const char *list, int *udp, int *tcp, int join)
     }
 
     if (addr_split_port(buf, sizeof(buf), &portname))
-      portname = nepim_global.portname;
+      portname = (char *) nepim_global.portname;
 
     *tcp += spawn_tcp_listener(buf, portname);
     *udp += nepim_udp_listener(buf, portname, join);
