@@ -18,14 +18,17 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: str.h,v 1.3 2005/11/04 09:56:15 evertonm Exp $ */
+/* $Id: str.h,v 1.4 2006/06/02 13:18:32 evertonm Exp $ */
 
 #ifndef NEPIM_STR_H
 #define NEPIM_STR_H
 
+int nepim_str_split(char sep, char *buf, int buf_size, char **next);
+int nepim_str_split_comma(char *buf, int buf_size, char **next);
+
 int addr_list_size(const char *list);
 int addr_list_get(const char *list, int i, char *buf, int buf_size);
 char *addr_list_append(char *list, const char *tail);
-int addr_split_port(char *buf, int buf_size, const char **port);
+int addr_split_port(char *buf, int buf_size, char **port);
 
 #endif /* NEPIM_STR_H */
