@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_client.c,v 1.72 2006/06/05 10:20:54 evertonm Exp $ */
+/* $Id: udp_client.c,v 1.73 2006/06/05 15:52:01 evertonm Exp $ */
 
 #include <stdio.h>
 #include <string.h>
@@ -375,7 +375,8 @@ static void *on_udp_read_segment(oop_source *src, int sd,
 
     udp_consume(slot, rd, &hdr);
 
-    udp_check_packet_data(sd, &hdr, &(slot->session), buf, UDP_HEADER_LEN, rd);
+    udp_check_packet_data(sd, &hdr, &(slot->session),
+			  (unsigned char *) buf, UDP_HEADER_LEN, rd);
   }
 
   return OOP_CONTINUE;
@@ -415,7 +416,7 @@ static int slot_greet_write(nepim_slot_t *slot)
   opt.write_ceil              = nepim_global.server_write_ceil;
 
   if (nepim_global.password) {
-    opt.password_buf      = nepim_global.password;
+    opt.password_buf      = (char *) nepim_global.password;
     opt.password_buf_size = strlen(nepim_global.password) + 1;
   }
   else {
@@ -1361,7 +1362,7 @@ static void parse_hosts(const char *host_list)
 
     /* split host/port */
     if (addr_split_port(hostname, sizeof(hostname), &portname))
-      portname = nepim_global.portname;
+      portname = (char *) nepim_global.portname;
 
     /* create sockets */
     for (i = 0; i < nepim_global.pipes; ++i) {
