@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_server.c,v 1.97 2006/06/05 10:20:54 evertonm Exp $ */
+/* $Id: udp_server.c,v 1.98 2006/06/05 15:52:01 evertonm Exp $ */
 
 
 #include <stdio.h>
@@ -1055,7 +1055,8 @@ static void *on_udp_segment(oop_source *src, int sd,
 
     udp_consume(slot, rd, &hdr);
 
-    udp_check_packet_data(sd, &hdr, &(slot->session), buf, UDP_HEADER_LEN, rd);
+    udp_check_packet_data(sd, &hdr, &(slot->session),
+			  (unsigned char *) buf, UDP_HEADER_LEN, rd);
   }
 
   return OOP_CONTINUE;
